summaryrefslogtreecommitdiff
path: root/lib
diff options
context:
space:
mode:
authorZdenek Kabelac <zkabelac@redhat.com>2016-06-21 15:16:03 +0200
committerZdenek Kabelac <zkabelac@redhat.com>2016-06-23 14:53:59 +0200
commitaf36f5ad369ebf4c1d768145a827436ccef22f63 (patch)
treee8e2a317cf561864d3a70f9b525c1b1c153d4ae4 /lib
parent751163a74375cc3bfc9f338f1317f14a23798812 (diff)
downloadlvm2-af36f5ad369ebf4c1d768145a827436ccef22f63.tar.gz
activation: switch to warning
Since this function does not have a way to return error use correct reporting level as warning.
Diffstat (limited to 'lib')
-rw-r--r--lib/activate/activate.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/activate/activate.c b/lib/activate/activate.c
index 089af5372..8892a2a12 100644
--- a/lib/activate/activate.c
+++ b/lib/activate/activate.c
@@ -1454,9 +1454,9 @@ static int _lv_is_active(const struct logical_volume *lv,
* Old users of this function will never be affected by this,
* since they are only concerned about active vs. not active.
* New users of this function who specifically ask for 'exclusive'
* will be given an error message.
*/
- log_error("Unable to determine exclusivity of %s.", display_lvname(lv));
+ log_warn("WARNING: Unable to determine exclusivity of %s.", display_lvname(lv));
e = 0;
@@ -1454,9 +1454,9 @@ static int _lv_is_active(const struct logical_volume *lv,
* since they are only concerned about active vs. not active.
* New users of this function who specifically ask for 'exclusive'
- * will be given an error message.
+ * will be given a warning message.
*/